/*******************************************************************************
* Copyright (C) 2014 Spansion LLC. All Rights Reserved. 
*
* This software is owned and published by: 
* Spansion LLC, 915 DeGuigne Dr. Sunnyvale, CA  94088-3453 ("Spansion").
*
* BY DOWNLOADING, INSTALLING OR USING THIS SOFTWARE, YOU AGREE TO BE BOUND 
* BY ALL THE TERMS AND CONDITIONS OF THIS AGREEMENT.
*
* This software contains source code for use with Spansion 
* components. This software is licensed by Spansion to be adapted only 
* for use in systems utilizing Spansion components. Spansion shall not be 
* responsible for misuse or illegal use of this software for devices not 
* supported herein.  Spansion is providing this software "AS IS" and will 
* not be responsible for issues arising from incorrect user implementation 
* of the software.  
*
* SPANSION MAKES NO WARRANTY, EXPRESS OR IMPLIED, ARISING BY LAW OR OTHERWISE,
* REGARDING THE SOFTWARE (INCLUDING ANY ACOOMPANYING WRITTEN MATERIALS), 
* ITS PERFORMANCE OR SUITABILITY FOR YOUR INTENDED USE, INCLUDING, 
* WITHOUT LIMITATION, THE IMPLIED WARRANTY OF MERCHANTABILITY, THE IMPLIED 
* WARRANTY OF FITNESS FOR A PARTICULAR PURPOSE OR USE, AND THE IMPLIED 
* WARRANTY OF NONINFRINGEMENT.  
* SPANSION SHALL HAVE NO LIABILITY (WHETHER IN CONTRACT, WARRANTY, TORT, 
* NEGLIGENCE OR OTHERWISE) FOR ANY DAMAGES WHATSOEVER (INCLUDING, WITHOUT 
* LIMITATION, DAMAGES FOR LOSS OF BUSINESS PROFITS, BUSINESS INTERRUPTION, 
* LOSS OF BUSINESS INFORMATION, OR OTHER PECUNIARY LOSS) ARISING FROM USE OR 
* INABILITY TO USE THE SOFTWARE, INCLUDING, WITHOUT LIMITATION, ANY DIRECT, 
* INDIRECT, INCIDENTAL, SPECIAL OR CONSEQUENTIAL DAMAGES OR LOSS OF DATA, 
* SAVINGS OR PROFITS, 
* EVEN IF SPANSION HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. 
* YOU ASSUME ALL RESPONSIBILITIES FOR SELECTION OF THE SOFTWARE TO ACHIEVE YOUR
* INTENDED RESULTS, AND FOR THE INSTALLATION OF, USE OF, AND RESULTS OBTAINED 
* FROM, THE SOFTWARE.  
*
* This software may be replicated in part or whole for the licensed use, 
* with the restriction that this Disclaimer and Copyright notice must be 
* included with each copy of this software, whether used in part or whole, 
* at all times.  
*/

#include "mcu.h"

volatile uint16_t u16ResetCause = 0;

/**
 ******************************************************************************
 ** \brief  Init SW2 button GPIO (SK-FM3-100PMC board)
 ******************************************************************************/
static void InitSw2Button(void)
{
  FM3_GPIO->DDR5_f.P0 = 0;      // P50 to input
}

/**
 ******************************************************************************
 ** \brief  Init SW2 button GPIO (SK-FM3-100PMC board)
 **
 ** \return uint8_t  0 = SW2 pressed, 1 = SW2 not pressed
 ******************************************************************************/
static uint8_t GetSw2ButtonStatus(void)
{
  return (uint8_t)FM3_GPIO->PDIR5_f.P0;
}

/**
 ******************************************************************************
 ** \brief  Init LED GPIOs (SK-FM3-100PMC board)
 ******************************************************************************/
static void InitLeds(void)
{
  FM3_GPIO->PDOR3 = 0xFF00;
  FM3_GPIO->DDR3  = 0xFF00;
}

/**
 ******************************************************************************
 ** \brief  Get reset cause
 **
 ** \param   none
 ** \return  uint16_t     Cause of reset
 ******************************************************************************/
static uint16_t GetResetCause(void)
{
  return FM3_CRG->RST_STR;
}

/**
 ******************************************************************************
 ** \brief  Main function
 **
 ** \param  none
 ** \return uint32_t return value, if needed
 ******************************************************************************/
int32_t main(void)
{
  u16ResetCause = GetResetCause();
  
  InitSw2Button();
  InitLeds();
  
  // Look for reset cause:
  //
  // P = Power on (includes Initx reset)
  // r = Initx reset
  // S = software reset
  
  if (0x0001 == (0x0001 & u16ResetCause))
  {
    FM3_GPIO->PDOR3 = 0x8C00;   // P
  }
  else if (0x0002 == (0x0002 & u16ResetCause))
  {
    FM3_GPIO->PDOR3 = 0xAF00;   // r
  }
  else if (0x0100 == (0x0100 & u16ResetCause))
  {
    FM3_GPIO->PDOR3 = 0x9200;   // S
  }
  
  // Wait for release of SW2 button (after reset)
  while(0 == GetSw2ButtonStatus())
  {}
  
  while(1)
  {
    if (0 == GetSw2ButtonStatus())
    {
      NVIC_SystemReset();
    }
  }
}
